#[non_exhaustive]pub enum LimitType {
Hard,
Soft,
Dynamic,
}Expand description
Set Peer Bandwidth’s Limit Type byte (5.4.5).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Hard
Peer SHOULD limit output to exactly the indicated window.
Soft
Peer SHOULD limit output to the indicated window or its current limit, whichever is smaller.
Dynamic
If the previous Limit Type was Hard, treat as Hard; otherwise ignore this message.
Implementations